@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: petris-board-commands.pl,v 1.3 1999/08/28 21:46:10 root Exp $
+# $Id: petris-board-commands.pl,v 1.4 1999/09/06 19:04:38 root Exp $
 
 # Copyright (c) Mark Summerfield 1998/9. All Rights Reserved.
 # May be used/distributed under the GPL.
@@ -21,14 +21,15 @@ sub create {
         ) ; 
 
     for( my $x = 0 ; $x < $Opt{BOARD_SQUARES_X} ; $x++ ) {
-        my $xlen = $x * $Opt{BOARD_SQUARE_LENGTH} ;
+        my $xlen = $x    * $Opt{BOARD_SQUARE_LENGTH} ;
+        my $Xlen = $xlen + $Opt{BOARD_SQUARE_LENGTH} ;
         for( my $y = 0 ; $y < $Opt{BOARD_SQUARES_Y} ; $y++ ) {
             my $ylen = $y * $Opt{BOARD_SQUARE_LENGTH} ;
             $Board{SQUARES}[$x][$y]{SQUARE} = $Board{CANVAS}->create(
                 'rectangle', 
                 $xlen,
                 $ylen,
-                $xlen + $Opt{BOARD_SQUARE_LENGTH},
+                $Xlen,
                 $ylen + $Opt{BOARD_SQUARE_LENGTH},
                 -fill    => $Const{BOARD_BACKGROUND_COLOUR},
                 -outline => $Const{BOARD_OUTLINE_COLOUR},
